@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP             #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
@@ -16,7 +15,7 @@ recent-enough version of @base@).
 -}
 module TextShow.Text.Read () where
 
-import Text.Read.Lex (Lexeme)
+import Text.Read.Lex (Lexeme, Number)
 
 import TextShow.Data.Char     ()
 import TextShow.Data.Integral ()
@@ -24,16 +23,9 @@ import TextShow.Data.List     ()
 import TextShow.Data.Maybe    ()
 import TextShow.Data.Ratio    ()
 import TextShow.TH.Internal (deriveTextShow)
-#if MIN_VERSION_base(4,6,0)
-import TextShow.TH.Names (numberTypeName)
-#endif
 
-#if MIN_VERSION_base(4,6,0)
--- | Only available with @base-4.6.0.0@ or later.
---
--- /Since: 2/
-$(deriveTextShow numberTypeName)
-#endif
+-- | /Since: 2/
+$(deriveTextShow ''Number)
 
 -- | /Since: 2/
 $(deriveTextShow ''Lexeme)
