@@ -1,6 +1,6 @@
 {-|
 Module:      Spec.Data.MaybeSpec
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -11,17 +11,19 @@ Portability: GHC
 module Spec.Data.MaybeSpec (main, spec) where
 
 import Data.Orphans ()
+import Data.Proxy.Compat (Proxy(..))
 
-import Spec.Utils (prop_matchesTextShow1, prop_genericTextShow, prop_genericTextShow1)
+import Spec.Utils (matchesTextShow1Spec, genericTextShowSpec, genericTextShow1Spec)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
-import Test.Hspec.QuickCheck (prop)
 
 main :: IO ()
 main = hspec spec
 
 spec :: Spec
 spec = parallel . describe "Maybe Int" $ do
-    prop "TextShow1 instance" (prop_matchesTextShow1 :: Int -> Maybe Int -> Bool)
-    prop "generic TextShow"   (prop_genericTextShow  :: Int -> Maybe Int -> Bool)
-    prop "generic TextShow1"  (prop_genericTextShow1 :: Int -> Maybe Int -> Bool)
+    let p :: Proxy (Maybe Int)
+        p = Proxy
+    matchesTextShow1Spec p
+    genericTextShowSpec  p
+    genericTextShow1Spec p
